# title-capitalization

A simple package to capitalize text according to title capitalization conventions.

Written for CSC630 in fall 2020 by Sarah, Gaia, Nikol, and Ali

Install using 

```pip install title-capitalization``` 

Import and use in Python using 

```
from titlecap import title
title = title.use_caps('demo title text')
```